import './index.less';
import { Layout, Tabs, Table } from 'antd';
import useUrlState from '@ahooksjs/use-url-state';
import { useMount } from 'ahooks'
import api from '../api/api'
import { useState } from 'react';
import timestampToTime from '@/utils';
import { useLocation, useRouteMatch } from 'umi';
import { useRequest } from 'ahooks';
const { TabPane } = Tabs;
type Detail = {
  Detail: string
  Env: string
  Host: string
  Port: number
  ServiceName: string
  UpTime: number
  Version?: string
}
const data: Detail[] = [
  // {
  //   Detail: "",
  //   Env: "qa",
  //   Host: "127.0.0.1",
  //   Port: 6910,
  //   ServiceName: "com.ywt.gapi.check_prescription.CheckPrescriptionService",
  //   UpTime: 1649995051,
  //   Version: "",
  // },
];
const data2: Detail[] = data.map(item => { return { ...item, Env: 'dev' } })
const data3: Detail[] = data.map(item => { return { ...item, Env: 'qa1' } })
const data4: Detail[] = data.map(item => { return { ...item, Env: 'prod' } })
export default function IndexPage() {
  const [key, setKey] = useState('qa')
  const [list, setList] = useState(data)
  const [tabsList, setTabsList] = useState([])
  const [label, setLabel] = useUrlState()
  const { loading, run} = useRequest(api.getGrpclist,{
    manual: true,
    onSuccess:(result)=>{
      setList(result)
    }
  })
  
  useMount(() => {
    initData()
  })

  const params = useRouteMatch();
  const location = useLocation();

  const columns = [
    {
      title: '服务名称',
      dataIndex: 'ServiceName',
    },
    {
      title: 'IP',
      dataIndex: 'Host',
    },
    {
      title: '端口',
      dataIndex: 'Port',
    },
    {
      title: 'Env',
      dataIndex: 'Env',
    },
    {
      title: '上线时间',
      dataIndex: 'UpTime',
      render: (text: number) => <a>{timestampToTime(text)}</a>
    },
    {
      title: '备注',
      dataIndex: 'Detail',
    },
  ];


  const initData = async () => {
    const tabs = await api.getenvsApi()
    const env = location.search.slice(5)
    run(env ? env : tabs[0])
    setTabsList(tabs)
    env && setLabel({ env })
    setKey(env ? env : tabs[0])
  }


  const tabChange = async (index: string) => {
    setKey(index)
    const instance = tabsList.find(item => item === index)
    if (instance) {
      run(instance)
      setLabel({ env: instance })
    }
  }


  return (
    <Layout>
      <div style={{ justifyContent: 'center' }}>
        <Tabs defaultActiveKey={key} activeKey={key} onChange={tabChange}>
          {tabsList.map((item) => {
            return (
              <TabPane tab={item} key={item} >

              </TabPane>
            )
          })}
        </Tabs>
        <Table
          columns={columns}
          dataSource={list}
          key="tablekey11"
          pagination={{pageSize: 100}}
          loading={loading}
        >
        </Table>
      </div>
    </Layout>
  );
}

